@@ -5,6 +5,6 @@ globalVariables(
         "week_of_month","week_day","fit","fft","time","x.y","y_actual","y_hat",
         "dff_trans","sma_order","sma_value","min_node","seasonal_period",
         "error","trend","season","damping","smooth_level","smooth_trend",
-        "smooth_seasonal"
+        "smooth_seasonal","name","printer"
     )
 )
